# {py:mod}`ngff_zarr.to_ngff_image`

```{py:module} ngff_zarr.to_ngff_image
```

```{autodoc2-docstring} ngff_zarr.to_ngff_image
:allowtitles:
```

## Module Contents

### Functions

````{list-table}
:class: autosummary longtable
:align: left

* - {py:obj}`to_ngff_image <ngff_zarr.to_ngff_image.to_ngff_image>`
  - ```{autodoc2-docstring} ngff_zarr.to_ngff_image.to_ngff_image
    :summary:
    ```
````

### API

````{py:function} to_ngff_image(data: typing.Union[numpy.typing.ArrayLike, collections.abc.MutableMapping, str, zarr.core.Array], dims: typing.Optional[typing.Sequence[ngff_zarr.zarr_metadata.SupportedDims]] = None, scale: typing.Optional[typing.Union[typing.Mapping[typing.Hashable, float]]] = None, translation: typing.Optional[typing.Union[typing.Mapping[typing.Hashable, float]]] = None, name: str = 'image', axes_units: typing.Optional[typing.Mapping[str, ngff_zarr.zarr_metadata.Units]] = None) -> ngff_zarr.ngff_image.NgffImage
:canonical: ngff_zarr.to_ngff_image.to_ngff_image

```{autodoc2-docstring} ngff_zarr.to_ngff_image.to_ngff_image
```
````
